==> Gridcoin-Research-5.3.3.0.tar.gz: Gridcoin-Research-5.3.3.0/src/qt/locale/bitcoin_kk_KZ.ts <==
<TS language="kk_KZ" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Жаңа адрес енгізу</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Жаңа</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Таңдаған адресті тізімнен жою</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Жою</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Құпия сөзді енгізу</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Жаңа құпия сөзі</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Жаңа құпия сөзді қайта енгізу</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>E&amp;xit</source>
        <translation>Шығу</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Параметрлері</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Құпия сөзді өзгерту</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Әмиян</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>Жіберу</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Алу</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Көмек</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Жаңартылған</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комиссия</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Комиссия алу кейін</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Растау саны</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Растық</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>таңба</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Адрес</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Информация</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комиссия:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Комиссия алу кейін:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Саны</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>қате</translation>
    </message>
</context>
</TS>

==> Gridcoin-Research-5.4.9.0.tar.gz: Gridcoin-Research-5.4.9.0/src/qt/locale/bitcoin_kk_KZ.ts <==
<TS language="kk_KZ" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Жаңа адрес енгізу</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Жаңа</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Таңдаған адресті тізімнен жою</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Жою</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Құпия сөзді енгізу</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Жаңа құпия сөзі</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Жаңа құпия сөзді қайта енгізу</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Әмиян</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>Жіберу</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Алу</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Шығу</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Параметрлері</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Құпия сөзді өзгерту</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Көмек</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Жаңартылған</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комиссия</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Комиссия алу кейін</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Растау саны</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Растық</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>таңба</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Адрес</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Информация</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комиссия:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Комиссия алу кейін:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Саны</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>қате</translation>
    </message>
</context>
</TS>
